pub struct Avatar {
avatar: TemplateChild<Avatar>,
data: BoundObject<AvatarData>,
image: BoundObjectWeakRef<AvatarImage>,
size: PhantomData<i32>,
watched_safety_setting: Cell<AvatarImageSafetySetting>,
watched_room: RefCell<Option<Room>>,
paintable_ref: RefCell<Option<CountedRef>>,
paintable_animation_ref: RefCell<Option<CountedRef>>,
watched_room_handler: RefCell<Option<SignalHandlerId>>,
watched_global_account_data_handler: RefCell<Option<SignalHandlerId>>,
}Fields
avatar: TemplateChild<Avatar>data: BoundObject<AvatarData>The AvatarData displayed by this widget.
image: BoundObjectWeakRef<AvatarImage>The AvatarImage watched by this widget.
size: PhantomData<i32>The size of the Avatar.
watched_safety_setting: Cell<AvatarImageSafetySetting>The safety setting to watch to decide whether the image of the avatar should be displayed.
watched_room: RefCell<Option<Room>>The room to watch to apply the current safety settings.
This is required if watched_safety_setting is not None.
paintable_ref: RefCell<Option<CountedRef>>paintable_animation_ref: RefCell<Option<CountedRef>>watched_room_handler: RefCell<Option<SignalHandlerId>>watched_global_account_data_handler: RefCell<Option<SignalHandlerId>>Implementations
Sourceimpl Avatar
impl Avatar
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl Avatar
impl Avatar
Sourcefn set_watched_safety_setting(&self, setting: AvatarImageSafetySetting)
fn set_watched_safety_setting(&self, setting: AvatarImageSafetySetting)
Set the safety setting to watch to decide whether the image of the avatar should be displayed.
Sourcefn set_watched_room(&self, room: Option<Room>)
fn set_watched_room(&self, room: Option<Room>)
Set the room to watch to apply the current safety settings.
Sourcefn connect_safety_setting_signals(&self)
fn connect_safety_setting_signals(&self)
Connect to the proper signals for the current safety setting.
Sourcefn disconnect_safety_setting_signals(&self)
fn disconnect_safety_setting_signals(&self)
Disconnect the handlers for the signals of the safety setting.
Sourcefn can_show_image(&self) -> bool
fn can_show_image(&self) -> bool
Whether we can display the image of the avatar with the current state.
Sourcefn set_data(&self, data: Option<AvatarData>)
fn set_data(&self, data: Option<AvatarData>)
Set the AvatarData displayed by this widget.
Sourcefn update_image(&self)
fn update_image(&self)
Set the AvatarImage watched by this widget.
Sourcefn needs_small_paintable(&self) -> bool
fn needs_small_paintable(&self) -> bool
Whether this avatar needs a small paintable.
Sourcefn update_scale_factor(&self)
fn update_scale_factor(&self)
Update the scale factor used to load the paintable.
Sourcefn update_paintable(&self)
fn update_paintable(&self)
Update the paintable for this avatar.
Sourcefn update_animated_paintable_state(&self)
fn update_animated_paintable_state(&self)
Update the state of the animated paintable for this avatar.